unit frmMain;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls;

type
  TfrmExtresViewer = class(TForm)
    GroupBoxSearch : TGroupBox;
    lblStart : TLabel;
    EditStart:TEdit;
    LblEnd:TLabel;
    EditEnd:TEdit;
    GroupBoxFound:TGroupBox;
    ListBoxFound:TListBox;
    GroupBoxData:TGroupBox;
    MemoData:TMemo;
    GroupBoxSelect:TGroupBox;
    EditFilename:TEdit;
    btnFindFile:TButton;
    btnView:TButton;
    OpenDialog:TOpenDialog;
    EditKey : TEdit;
    RadioButtonDefault : TRadioButton;
    RadioButtonCustom : TRadioButton;
    procedure btnFindFileClick(Sender: TObject);
    procedure btnViewClick(Sender: TObject);
    procedure ListBoxFoundClick(Sender: TObject);
    procedure EditKeyExit(Sender: TObject);
    procedure RadioButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmExtresViewer: TfrmExtresViewer;

implementation
uses extres;

{$R *.dfm}

procedure TfrmExtresViewer.btnFindFileClick(Sender: TObject);
begin
  if OpenDialog.Execute then
  begin
    EditFilename.Text := OpenDialog.FileName;
    btnView.Enabled := true;
    ListBoxFound.Clear;
    MemoData.Lines.Clear;
    GroupBoxData.Caption := 'Data of Resource #';
  end
  else
    btnView.Enabled := false;

end;

procedure TfrmExtresViewer.btnViewClick(Sender: TObject);
var
  Key : array[0..16] of char;
  ErrStr : array[0..256] of char;
  extResHandle : THandle;
  size : longint;
  i,i_end, Code : integer;
  p_str : LPSTR;
  value : string;
begin
  ListBoxFound.Clear;
  MemoData.Lines.Clear;
  GroupBoxData.Caption := 'Data of Resource #';

  extResHandle := _extResLoad(PChar(EditFilename.Text));
  if extResHandle = 0 then
  begin
    _extResLastError(ErrStr, 255);
    ShowMessage(ErrStr);
    exit;
  end;

  if RadioButtonCustom.Checked and (Length(EditKey.Text) = 16) then
  begin
    if _extResSetKey(extResHandle, pChar(EditKey.Text)) = 0 then   // Set Encryption key
    begin
      _extResLastError(errStr, 256);
      ShowMessage(errStr);
      exit;
    end;
  end;
  

  Val(EditStart.Text, i, Code);
  Val(EditEnd.Text, i_end, Code);

  for i:=i to i_end do
  begin
    p_str := _extResGet(extResHandle, i, size);
    if size > 0 then
    begin
      _extResFree(p_str);
      Str(i, value);
      ListBoxFound.Items.Add(value);
    end;
  end;
  _extResUnload(extResHandle);
end;

procedure TfrmExtresViewer.ListBoxFoundClick(Sender: TObject);
var
  extResHandle : THandle;
  errStr : array[0..256] of char;
  size : longint;
  Value, Code : integer;
  str:LPSTR;
begin
  extResHandle := _extResLoad(pChar(EditFilename.Text));
  if extResHandle = 0 then
  begin
    _extResLastError(errStr, 256);
    ShowMessage(errStr);
    exit;
  end;

  if RadioButtonCustom.Checked and (Length(EditKey.Text) = 16) then
  begin
    if _extResSetKey(extResHandle, pChar(EditKey.Text)) = 0 then   // Set Encryption key
    begin
      _extResLastError(errStr, 256);
      ShowMessage(errStr);
      exit;
    end;
  end;

  Val(ListBoxFound.Items.Strings[ListBoxFound.ItemIndex],Value, Code);

  str := _extResGet(extResHandle, Value, size);
  if size > 0 then
  begin
    MemoData.Lines.Clear;
    MemoData.Lines.Add(str);
    GroupBoxData.Caption := 'Data of Resource #' + ListBoxFound.Items.Strings[ListBoxFound.ItemIndex];
    _extResFree(str);
  end;
  _extResUnload(extResHandle);

end;

procedure TfrmExtresViewer.EditKeyExit(Sender: TObject);
begin
  if RadioButtonDefault.Focused then  // Key does not matter if user clicked on Default radiobutton
    exit;
  if Length(EditKey.Text) <> 16 then
  begin
     MessageDlg('Encryptionkey must be 16 bytes.',  mtInformation, [mbOK], 0);
     EditKey.SetFocus;
  end


end;

procedure TfrmExtresViewer.RadioButtonClick(Sender: TObject);
begin
  EditKey.Enabled := RadioButtonCustom.Checked;

  if(EditKey.Enabled)then
  begin
    EditKey.SetFocus;
  end;
end;

end.
